@@ -128,8 +128,11 @@ REGEX_BASE64_64FORMAT = re.compile("""
 
 def hex_xformat_encode(v: bytes) -> str:
     """
-    Encode in X'{hex}' format.
+    Encode in ``X'{hex}'`` format.
     Example:
+
+    .. code-block:: none
+
         special_hex_encode(b"hello") == "X'68656c6c6f'"
     """
     return "X'{}'".format(binascii.hexlify(v).decode("ascii"))
@@ -137,8 +140,11 @@ def hex_xformat_encode(v: bytes) -> str:
 
 def hex_xformat_decode(s: str) -> Optional[bytes]:
     """
-    Reverse hex_xformat_encode().
+    Reverse ``hex_xformat_encode()``.
     The parameter is a hex-encoded BLOB like
+
+    .. code-block:: none
+
         "X'CDE7A24B1A9DBA3148BCB7A0B9DA5BB6A424486C'"
     """
     # SPECIAL HANDLING for BLOBs: a string like X'01FF' means a hex-
@@ -158,8 +164,11 @@ def hex_xformat_decode(s: str) -> Optional[bytes]:
 
 def base64_64format_encode(v: bytes) -> str:
     """
-    Encode in 64'{base64encoded}' format.
+    Encode in ``64'{base64encoded}'`` format.
     Example:
+
+    .. code-block:: none
+
         base64_64format_encode(b"hello") == "64'aGVsbG8='"
     """
     return "64'{}'".format(base64.b64encode(v).decode('ascii'))
@@ -167,7 +176,7 @@ def base64_64format_encode(v: bytes) -> str:
 
 def base64_64format_decode(s: str) -> Optional[bytes]:
     """
-    Reverse base64_64format_encode().
+    Reverse ``base64_64format_encode()``.
     """
     # THIS IS ANOTHER WAY OF DOING BLOBS: base64 encoding
     # e.g. a string like 64'cGxlYXN1cmUu' is a base-64-encoded BLOB
