@@ -52,9 +52,17 @@ def merge_dicts(*dict_args: Dict) -> Dict:
 def merge_two_dicts(x: Dict, y: Dict) -> Dict:
     """
     Given two dicts, merge them into a new dict as a shallow copy, e.g.
+
+    .. code-block:: python
+
         z = merge_two_dicts(x, y)
+
     If you can guarantee Python 3.5, then a simpler syntax is:
+
+    .. code-block:: python
+
         z = {**x, **y}
+
     See http://stackoverflow.com/questions/38987
     """
     z = x.copy()
@@ -179,8 +187,8 @@ def delete_keys(d: Dict[Any, Any],
 
 class LazyDict(dict):
     """
-    The *args/**kwargs parts are useful, but we don't want to have to name
-    'thunk' explicitly.
+    The ``*args``/``**kwargs`` parts are useful, but we don't want to have to
+    name 'thunk' explicitly.
     """
     def get(self, key: Hashable, thunk: Any = None,
             *args: Any, **kwargs: Any) -> Any:
@@ -204,8 +212,8 @@ class LazyDict(dict):
 class LazyButHonestDict(dict):
     """
     Compared to the StackOverflow version: no obvious need to have a default
-    returning None, when we're implementing this as a special function.
-    In contrast, helpful to have *args/**kwargs options.
+    returning ``None``, when we're implementing this as a special function.
+    In contrast, helpful to have ``*args``/``**kwargs`` options.
     """
     def lazyget(self, key: Hashable, thunk: Callable,
                 *args: Any, **kwargs: Any) -> Any:
