@@ -48,7 +48,7 @@ log.addHandler(logging.NullHandler())
 def iso_string_to_python_datetime(
         isostring: str) -> Optional[datetime.datetime]:
     """
-    Takes an ISO-8601 string and returns a datetime.
+    Takes an ISO-8601 string and returns a ``datetime``.
     """
     if not isostring:
         return None  # if you parse() an empty string, you get today's date
@@ -67,8 +67,8 @@ def python_utc_datetime_to_sqlite_strftime_string(
 
 def python_localized_datetime_to_human_iso(value: datetime.datetime) -> str:
     """
-    Converts a Python datetime that has a timezone to an ISO-8601 string
-    with ":" between the hours and minutes of the timezone.
+    Converts a Python ``datetime`` that has a timezone to an ISO-8601 string
+    with ``:`` between the hours and minutes of the timezone.
 
     Example:
         >>> import datetime
@@ -90,60 +90,76 @@ class IsoDateTimeTzField(models.CharField):
     Django field for date/time stored in ISO format.
     Microsecond resolution; timezone-aware.
     Example sent TO the database:
+
+    .. code-block:: none
+
         2015-11-11T22:21:37.000000+05:00
 
         YYYY-MM-DD HH:MM:SS uuuuuu TZ:TZ
         1234567890123456789012345678901234567890 ... so 32 chars
 
     Will also accept FROM the database any ISO-8601 format accepted by
-    dateutil.parser.parse()
+    ``dateutil.parser.parse()``
 
-    - Python side: datetime.datetime
+    - Python side: ``datetime.datetime``
 
-    - The database-specific bits are a tricky.
+    - The database-specific bits are tricky.
 
-        In SQLite, the DATETIME() and STRFTIME() functions can be used to
-        convert ISO strings to UTC, so that's a good basis for comparison.
+      - In SQLite, the ``DATETIME()`` and ``STRFTIME()`` functions can be used
+        to convert ISO strings to UTC, so that's a good basis for comparison.
         However, the actual comparisons, as always in SQLite, are string-based.
 
-        DATETIME(...) ends up like this:
+      - ``DATETIME(...)`` ends up like this:
+
+        .. code-block:: none
+
             2015-11-11 22:21:37
 
-        STRFTIME('%Y-%m-%d %H:%M:%f', ...) looks like this, allowing
+        ``STRFTIME('%Y-%m-%d %H:%M:%f', ...)`` looks like this, allowing
         millisecond precision:
+
+        .. code-block:: none
+
             2015-11-11 22:21:37.000
             2015-11-11 22:21:37.123
 
         The Django automatic RHS converter for datetime values looks like this:
+
+        .. code-block:: none
+
             2015-11-11 22:21:37
             2015-11-11 22:21:37.123456
 
-            ... http://stackoverflow.com/questions/14368290/django-datetimefield-and-timezone-now  # noqa
+        ... http://stackoverflow.com/questions/14368290/django-datetimefield-and-timezone-now
 
-        ... so a direct comparison with DATETIME works only if the microsecond
-        component is zero (or you coerce it to zero via get_db_prep_value), and
-        a direct comparison to the STRFTIME expression fails.
+        ... so a direct comparison with ``DATETIME`` works only if the
+        microsecond component is zero (or you coerce it to zero via
+        ``get_db_prep_value``), and a direct comparison to the ``STRFTIME``
+        expression fails.
 
-        Coercing the fractional seconds to zero via get_db_prep_value() would
-        make sub-second comparisons meaningless in the database. So we should
-        avoid that, and operate as close to the database resolution as
+        Coercing the fractional seconds to zero via ``get_db_prep_value()``
+        would make sub-second comparisons meaningless in the database. So we
+        should avoid that, and operate as close to the database resolution as
         possible.
 
         That means that we have to alter the RHS in the same way we altered the
         LHS, and that means we can't use a transform...
-        ... oh, hang on, I'm just underestimating get_db_prep_value(); we can
-        coerce to exactly the thing yielded by SQLite's STRFTIME, by converting
-        to a string!
+        ... oh, hang on, I'm just underestimating ``get_db_prep_value()``; we
+        .can coerce to exactly the thing yielded by SQLite's ``STRFTIME``, by
+        .converting to a string!
 
         Next step: the data conversion specified for the RHS of a transform is
-        governed by its output_field. So when we're coercing to a date, we
-        specify a DateField here, and all is happy. But for a datetime, we
-        should NOT specify DateTimeField, because that will bypass the equality
-        lookup from our custom field, and also bypass the RHS conversion (via
-        get_db_prep_value() etc.).
+        governed by its ``output_field``. So when we're coercing to a date, we
+        specify a ``DateField`` here, and all is happy. But for a ``datetime``,
+        we should NOT specify ``DateTimeField``, because that will bypass the
+        equality lookup from our custom field, and also bypass the RHS
+        conversion (via ``get_db_prep_value()`` etc.).
 
-        Specifically, for a DateTimeField, conversion to a database value is
+        Specifically, for a ``DateTimeField``, conversion to a database value is
         done by
+
+        .. code-block:: none
+
             django/db/models/fields/__init__.py : DateTimeField.get_prep_value
             django/db/backends/{backend}/operations.py
                 : DatabaseOperations.value_to_db_datetime
@@ -151,28 +167,33 @@ class IsoDateTimeTzField(models.CharField):
                   and for a datetime, that gives
                     2015-11-17 00:00:00  # if microsecond == 0
                     2015-11-17 00:00:00.001000  # if microsecond != 0
-            So for a proper conversion, we need to convert SQLite stuff to
-            that. The MySQL backend does the same thing, but MySQL has a
-            concept of a datetime anyway.
+
+        So for a proper conversion, we need to convert SQLite stuff to that.
+        The MySQL backend does the same thing, but MySQL has a concept of a
+        datetime anyway.
 
     - For MySQL, see also:
 
-        https://docs.djangoproject.com/en/1.8/ref/databases/#fractional-seconds-support-for-time-and-datetime-fields  # noqa
+        https://docs.djangoproject.com/en/1.8/ref/databases/#fractional-seconds-support-for-time-and-datetime-fields
 
-    """
+    """  # noqa
     # https://docs.djangoproject.com/en/1.8/ref/models/fields/#field-api-reference  # noqa
 
     description = "ISO-8601 date/time field with timezone, stored as text"
 
     def __init__(self, *args, **kwargs) -> None:
-        """Declare that we're a VARCHAR(32) on the database side."""
+        """
+        Declare that we're a ``VARCHAR(32)`` on the database side.
+        """
         # https://docs.djangoproject.com/en/1.8/howto/custom-model-fields/
         kwargs['max_length'] = 32
         super().__init__(*args, **kwargs)
 
     def deconstruct(self) -> Tuple[str, str, List[Any], Dict[str, Any]]:
-        """Takes an instance and calculates the arguments to pass to __init__
-        to reconstruct it."""
+        """
+        Takes an instance and calculates the arguments to pass to ``__init__``
+        to reconstruct it.
+        """
         name, path, args, kwargs = super().deconstruct()
         del kwargs['max_length']
         return name, path, args, kwargs
@@ -192,10 +213,10 @@ class IsoDateTimeTzField(models.CharField):
 
     def to_python(self, value: Optional[str]) -> Optional[Any]:
         """
-        Called during deserialization and during form clean() calls.
-        Must deal with an instance of the correct type; a string; or None
-        (if the field allows null=True).
-        Should raise ValidationError if problems.
+        Called during deserialization and during form ``clean()`` calls.
+        Must deal with an instance of the correct type; a string; or ``None``
+        (if the field allows ``null=True``).
+        Should raise ``ValidationError`` if problems.
         """
         # https://docs.djangoproject.com/en/1.8/howto/custom-model-fields/
         # log.debug("to_python: {}, {}".format(value, type(value)))
@@ -212,7 +233,7 @@ class IsoDateTimeTzField(models.CharField):
         Convert Python value to database value for QUERYING.
         We query with UTC, so this function converts datetime values to UTC.
 
-        Calls to this function are followed by calls to get_db_prep_value(),
+        Calls to this function are followed by calls to ``get_db_prep_value()``,
         which is for backend-specific conversions.
         """
         log.debug("get_prep_value: {}, {}".format(value, type(value)))
@@ -227,7 +248,7 @@ class IsoDateTimeTzField(models.CharField):
     def get_db_prep_value(self, value, connection, prepared=False):
         """
         Further conversion of Python value to database value for QUERYING.
-        This follows get_prep_value(), and is for backend-specific stuff.
+        This follows ``get_prep_value()``, and is for backend-specific stuff.
         See notes above.
         """
         log.debug("get_db_prep_value: {}, {}".format(value, type(value)))
@@ -259,6 +280,11 @@ class IsoDateTimeTzField(models.CharField):
 # -----------------------------------------------------------------------------
 
 def iso_string_to_sql_utcdatetime_mysql(x: str) -> str:
+    """
+    Provides MySQL SQL to convert an ISO-8601-format string (with punctuation)
+    to a ``DATETIME`` in UTC. The argument ``x`` is the SQL expression to be
+    converted (such as a column name).
+    """
     return (
         "CONVERT_TZ(STR_TO_DATE(LEFT({x}, 26),"
         "                       '%Y-%m-%dT%H:%i:%s.%f'),"
@@ -273,6 +299,11 @@ def iso_string_to_sql_utcdatetime_mysql(x: str) -> str:
 
 
 def iso_string_to_sql_utcdate_mysql(x: str) -> str:
+    """
+    Provides MySQL SQL to convert an ISO-8601-format string (with punctuation)
+    to a ``DATE`` in UTC. The argument ``x`` is the SQL expression to be
+    converted (such as a column name).
+    """
     return (
         "DATE(CONVERT_TZ(STR_TO_DATE(LEFT({x}, 26),"
         "                            '%Y-%m-%dT%H:%i:%s.%f'),"
@@ -282,6 +313,12 @@ def iso_string_to_sql_utcdate_mysql(x: str) -> str:
 
 
 def iso_string_to_sql_date_mysql(x: str) -> str:
+    """
+    Provides MySQL SQL to convert an ISO-8601-format string (with punctuation)
+    to a ``DATE``, just by taking the date fields (without any timezone
+    conversion). The argument ``x`` is the SQL expression to be converted (such
+    as a column name).
+    """
     return "STR_TO_DATE(LEFT({x}, 10), '%Y-%m-%d')".format(x=x)
 
 
@@ -291,10 +328,19 @@ def iso_string_to_sql_date_mysql(x: str) -> str:
 
 def iso_string_to_sql_utcdatetime_sqlite(x: str) -> str:
     """
+    Provides SQLite SQL to convert a column to a ``DATETIME`` in UTC. The
+    argument ``x`` is the SQL expression to be converted (such as a column
+    name).
+
     Output like:
+
+    .. code-block:: none
+
         2015-11-14 18:52:47.000
         2015-11-14 18:52:47.247
-    Don't use DATETIME; using STRFTIME allows millsecond precision.
+
+    Internally, we don't use ``DATETIME()``; using ``STRFTIME()`` allows
+    millsecond precision.
     """
     return "STRFTIME('%Y-%m-%d %H:%M:%f', {x})".format(x=x)
     # This doesn't mind the 'T' in the middle, rounds to millisecond precision,
@@ -308,13 +354,24 @@ def iso_string_to_sql_utcdatetime_sqlite(x: str) -> str:
 
 def iso_string_to_sql_utcdatetime_pythonformat_sqlite(x: str) -> str:
     """
+    Provides SQLite SQL to convert a column to a ``DATETIME`` in UTC, in a
+    string format that matches a common Python format. The argument ``x`` is
+    the SQL expression to be converted (such as a column name).
+
     Output like
+
+    .. code-block:: none
+
         2015-11-14 18:52:47
         2015-11-14 18:52:47.247000
-    ... i.e. gets rid of trailing '.000' for zero milliseconds, appends
-        trailing '000' for everything else,
-    ... thus matching the output of Python's str(x) where x is a datetime.
-    ... thus matching the RHS of a Django default datetime comparison.
+
+    i.e.
+
+    - gets rid of trailing ``.000`` for zero milliseconds, appends
+      trailing ``000`` for everything else,
+    - ... thus matching the output of Python's ``str(x)`` where ``x`` is a
+      ``datetime``.
+    - ... thus matching the RHS of a Django default ``datetime`` comparison.
     """
     return """
         CASE SUBSTR(STRFTIME('%f', {x}), 4, 3)
@@ -325,10 +382,19 @@ def iso_string_to_sql_utcdatetime_pythonformat_sqlite(x: str) -> str:
 
 
 def iso_string_to_sql_utcdate_sqlite(x: str) -> str:
+    """
+    Provides SQLite SQL to convert a column to a ``DATE`` in UTC. The argument
+    ``x`` is the SQL expression to be converted (such as a column name).
+    """
     return "DATE({x})".format(x=x)
 
 
 def iso_string_to_sql_date_sqlite(x: str) -> str:
+    """
+    Provides SQLite SQL to convert a column to a ``DATE``, just by taking the
+    date fields (without any timezone conversion). The argument ``x`` is the
+    SQL expression to be converted (such as a column name).
+    """
     return "DATE(SUBSTR({x}, 1, 10))".format(x=x)
 
 
@@ -338,6 +404,11 @@ def iso_string_to_sql_date_sqlite(x: str) -> str:
 
 def isodt_lookup_mysql(lookup, compiler, connection,
                        operator) -> Tuple[str, Any]:
+    """
+    For a comparison "LHS *op* RHS", transforms the LHS from a column
+    containing an ISO-8601 date/time into an SQL ``DATETIME``,
+    for MySQL.
+    """
     lhs, lhs_params = compiler.compile(lookup.lhs)
     rhs, rhs_params = lookup.process_rhs(compiler, connection)
     params = lhs_params + rhs_params
@@ -350,6 +421,11 @@ def isodt_lookup_mysql(lookup, compiler, connection,
 
 def isodt_lookup_sqlite(lookup, compiler, connection,
                         operator) -> Tuple[str, Any]:
+    """
+    For a comparison "LHS *op* RHS", transforms the LHS from a column
+    containing an ISO-8601 date/time into an SQL ``DATETIME``,
+    for SQLite.
+    """
     lhs, lhs_params = compiler.compile(lookup.lhs)
     rhs, rhs_params = lookup.process_rhs(compiler, connection)
     params = lhs_params + rhs_params
@@ -365,6 +441,10 @@ def isodt_lookup_sqlite(lookup, compiler, connection,
 # noinspection PyAbstractClass
 @IsoDateTimeTzField.register_lookup
 class IsoDateTimeLessThan(models.Lookup):
+    """
+    Lookup for a '<' comparison where the LHS is a column containing an
+    ISO-8601 field (and the RHS will be comparable to a ``DATETIME``).
+    """
     lookup_name = 'lt'
 
     def as_mysql(self, compiler, connection) -> Tuple[str, Any]:
@@ -377,6 +457,10 @@ class IsoDateTimeLessThan(models.Lookup):
 # noinspection PyAbstractClass
 @IsoDateTimeTzField.register_lookup
 class IsoDateTimeLessThanEqual(models.Lookup):
+    """
+    Lookup for a '<=' comparison where the LHS is a column containing an
+    ISO-8601 field (and the RHS will be comparable to a ``DATETIME``).
+    """
     lookup_name = 'lte'
 
     def as_mysql(self, compiler, connection) -> Tuple[str, Any]:
@@ -389,6 +473,10 @@ class IsoDateTimeLessThanEqual(models.Lookup):
 # noinspection PyAbstractClass
 @IsoDateTimeTzField.register_lookup
 class IsoDateTimeExact(models.Lookup):
+    """
+    Lookup for a '=' comparison where the LHS is a column containing an
+    ISO-8601 field (and the RHS will be comparable to a ``DATETIME``).
+    """
     lookup_name = 'exact'
 
     def as_mysql(self, compiler, connection) -> Tuple[str, Any]:
@@ -401,6 +489,10 @@ class IsoDateTimeExact(models.Lookup):
 # noinspection PyAbstractClass
 @IsoDateTimeTzField.register_lookup
 class IsoDateTimeGreaterThan(models.Lookup):
+    """
+    Lookup for a '>' comparison where the LHS is a column containing an
+    ISO-8601 field (and the RHS will be comparable to a ``DATETIME``).
+    """
     lookup_name = 'gt'
 
     def as_mysql(self, compiler, connection) -> Tuple[str, Any]:
@@ -413,6 +505,10 @@ class IsoDateTimeGreaterThan(models.Lookup):
 # noinspection PyAbstractClass
 @IsoDateTimeTzField.register_lookup
 class IsoDateTimeGreaterThanEqual(models.Lookup):
+    """
+    Lookup for a '>=' comparison where the LHS is a column containing an
+    ISO-8601 field (and the RHS will be comparable to a ``DATETIME``).
+    """
     lookup_name = 'gte'
 
     def as_mysql(self, compiler, connection) -> Tuple[str, Any]:
