@@ -22,10 +22,12 @@
 
 ===============================================================================
 
-- We were using django-picklefield and PickledObjectField.
+- We were using ``django-picklefield`` and ``PickledObjectField``.
+
 - However, this fails in a nasty way if you add new attributes to a class
   that has been pickled, and anyway pickle is insecure (as it trusts its
   input).
+  
 - JSON is better.
   http://www.benfrederickson.com/dont-pickle-your-data/
 
@@ -47,74 +49,75 @@
 
 e.g.:
 
-
-import inspect
-import json
-from typing import Any, Dict, Union
-
-class Thing(object):
-    def __init__(self, a: int = 1, b: str = ''):
-        self.a = a
-        self.b = b
-    def __repr__(self) -> str:
-        return "<Thing(a={}, b={}) at {}>".format(
-            repr(self.a), repr(self.b), hex(id(self)))
-
-
-MY_JSON_TYPES = {
-    'Thing': Thing,
-}
-TYPE_LABEL = '__type__'
-
-class MyEncoder(json.JSONEncoder):
-    def default(self, obj: Any) -> Any:
-        typename = type(obj).__name__
-        if typename in MY_JSON_TYPES.keys():
-            d = obj.__dict__
-            d[TYPE_LABEL] = typename
-            return d
-        return super().default(obj)
-
-
-class MyDecoder(json.JSONDecoder):  # INADEQUATE for nested things
-    def decode(self, s: str) -> Any:
-        o = super().decode(s)
-        if isinstance(o, dict):
-            typename = o.get(TYPE_LABEL, '')
+.. code-block:: python
+    
+    import inspect
+    import json
+    from typing import Any, Dict, Union
+    
+    class Thing(object):
+        def __init__(self, a: int = 1, b: str = ''):
+            self.a = a
+            self.b = b
+        def __repr__(self) -> str:
+            return "<Thing(a={}, b={}) at {}>".format(
+                repr(self.a), repr(self.b), hex(id(self)))
+    
+    
+    MY_JSON_TYPES = {
+        'Thing': Thing,
+    }
+    TYPE_LABEL = '__type__'
+    
+    class MyEncoder(json.JSONEncoder):
+        def default(self, obj: Any) -> Any:
+            typename = type(obj).__name__
+            if typename in MY_JSON_TYPES.keys():
+                d = obj.__dict__
+                d[TYPE_LABEL] = typename
+                return d
+            return super().default(obj)
+    
+    
+    class MyDecoder(json.JSONDecoder):  # INADEQUATE for nested things
+        def decode(self, s: str) -> Any:
+            o = super().decode(s)
+            if isinstance(o, dict):
+                typename = o.get(TYPE_LABEL, '')
+                if typename and typename in MY_JSON_TYPES:
+                    classtype = MY_JSON_TYPES[typename]
+                    o.pop(TYPE_LABEL)
+                    return classtype(**o)
+            return o
+    
+    
+    def my_decoder_hook(d: Dict) -> Any:
+        if TYPE_LABEL in d:
+            typename = d.get(TYPE_LABEL, '')
             if typename and typename in MY_JSON_TYPES:
                 classtype = MY_JSON_TYPES[typename]
-                o.pop(TYPE_LABEL)
-                return classtype(**o)
-        return o
-
-
-def my_decoder_hook(d: Dict) -> Any:
-    if TYPE_LABEL in d:
-        typename = d.get(TYPE_LABEL, '')
-        if typename and typename in MY_JSON_TYPES:
-            classtype = MY_JSON_TYPES[typename]
-            d.pop(TYPE_LABEL)
-            return classtype(**d)
-    return d
-
-
-x = Thing(a=5, b="hello")
-y = [1, x, 2]
-
-# Encoding:
-j = MyEncoder().encode(x)  # OK
-j2 = json.dumps(x, cls=MyEncoder)  # OK; same result
-
-k = MyEncoder().encode(y)  # OK
-k2 = json.dumps(y, cls=MyEncoder)  # OK; same result
-
-# Decoding
-x2 = MyDecoder().decode(j)  # OK, but simple structure
-y2 = MyDecoder().decode(k)  # FAILS
-y3 = json.JSONDecoder(object_hook=my_decoder_hook).decode(k)  # SUCCEEDS
-
-print(repr(x))
-print(repr(x2))
+                d.pop(TYPE_LABEL)
+                return classtype(**d)
+        return d
+    
+    
+    x = Thing(a=5, b="hello")
+    y = [1, x, 2]
+    
+    # Encoding:
+    j = MyEncoder().encode(x)  # OK
+    j2 = json.dumps(x, cls=MyEncoder)  # OK; same result
+    
+    k = MyEncoder().encode(y)  # OK
+    k2 = json.dumps(y, cls=MyEncoder)  # OK; same result
+    
+    # Decoding
+    x2 = MyDecoder().decode(j)  # OK, but simple structure
+    y2 = MyDecoder().decode(k)  # FAILS
+    y3 = json.JSONDecoder(object_hook=my_decoder_hook).decode(k)  # SUCCEEDS
+    
+    print(repr(x))
+    print(repr(x2))
 
 """  # noqa
 
@@ -132,6 +135,9 @@ from cardinal_pythonlib.json.serialize import json_decode, json_encode
 # =============================================================================
 
 class JsonClassField(TextField):
+    """
+    Django field that serializes Python objects into JSON.
+    """
     # https://docs.djangoproject.com/en/1.10/howto/custom-model-fields/
     description = "Python objects serialized into JSON"
 
@@ -156,8 +162,8 @@ class JsonClassField(TextField):
         the correct type; (*) a string; (*) None (if the field allows
         null=True)."
 
-        "For to_python(), if anything goes wrong during value conversion, you
-        should raise a ValidationError exception."
+        "For ``to_python()``, if anything goes wrong during value conversion,
+        you should raise a ``ValidationError`` exception."
         """
         if value is None:
             return value
@@ -170,7 +176,7 @@ class JsonClassField(TextField):
 
     def get_prep_value(self, value):
         """
-        Converse of to_python(). Converts Python objects back to query
+        Converse of ``to_python()``. Converts Python objects back to query
         values.
         """
         return json_encode(value)
