@@ -40,19 +40,23 @@ from django.utils.translation import ugettext_lazy
 
 class ContentTypeRestrictedFileField(models.FileField):
     """
-    Same as FileField, but you can specify:
-        * content_types - list containing allowed content_types.
-          Example: ['application/pdf', 'image/jpeg']
-        * max_upload_size - a number indicating the maximum file size allowed
-          for upload.
-            2.5MB - 2621440
-            5MB - 5242880
-            10MB - 10485760
-            20MB - 20971520
-            50MB - 5242880
-            100MB - 104857600
-            250MB - 214958080
-            500MB - 429916160
+    Same as ``FileField``, but you can specify:
+
+    - ``content_types`` - list containing allowed content_types.
+      Example: ``['application/pdf', 'image/jpeg']``
+    - ``max_upload_size`` - a number indicating the maximum file size allowed
+      for upload.
+
+      .. code-block:: none
+
+        2.5MB - 2621440
+        5MB - 5242880
+        10MB - 10485760
+        20MB - 20971520
+        50MB - 5242880
+        100MB - 104857600
+        250MB - 214958080
+        500MB - 429916160
     """
     def __init__(self, *args, **kwargs) -> None:
         self.content_types = kwargs.pop("content_types", None)
