@@ -35,6 +35,10 @@ from cardinal_pythonlib.nhs import is_valid_nhs_number
 # =============================================================================
 
 def clean_int(x) -> int:
+    """
+    Returns its parameter as an integer, or raises
+    ``django.forms.ValidationError``.
+    """
     try:
         return int(x)
     except ValueError:
@@ -43,6 +47,10 @@ def clean_int(x) -> int:
 
 
 def clean_nhs_number(x) -> int:
+    """
+    Returns its parameter as a valid integer NHS number, or raises
+    ``django.forms.ValidationError``.
+    """
     try:
         x = int(x)
         if not is_valid_nhs_number(x):
@@ -54,6 +62,9 @@ def clean_nhs_number(x) -> int:
 
 
 class MultipleIntAreaField(forms.Field):
+    """
+    Django ``forms.Field`` to capture multiple integers.
+    """
     # See also http://stackoverflow.com/questions/29303902/django-form-with-list-of-integers  # noqa
     widget = forms.Textarea
 
@@ -62,6 +73,9 @@ class MultipleIntAreaField(forms.Field):
 
 
 class MultipleNhsNumberAreaField(forms.Field):
+    """
+    Django ``forms.Field`` to capture multiple NHS numbers.
+    """
     widget = forms.Textarea
 
     def clean(self, value) -> List[int]:
@@ -69,6 +83,9 @@ class MultipleNhsNumberAreaField(forms.Field):
 
 
 class MultipleWordAreaField(forms.Field):
+    """
+    Django ``forms.Field`` to capture multiple words.
+    """
     widget = forms.Textarea
 
     def clean(self, value) -> List[str]:
@@ -76,5 +93,8 @@ class MultipleWordAreaField(forms.Field):
 
 
 class SingleNhsNumberField(forms.IntegerField):
+    """
+    Django ``forms.Field`` to capture a single NHS number.
+    """
     def clean(self, value) -> int:
         return clean_nhs_number(value)
