@@ -30,7 +30,9 @@
         https://bitbucket.org/zzzeek/dogpile.cache/issues/96/error-in-python-35-with-use-of-deprecated
 
     This fixes a crash using type-hinted functions under Python 3.5 with 
-    dogpile.cache==0.6.4:
+    ``dogpile.cache==0.6.4``:
+    
+    .. code-block:: none
 
         Traceback (most recent call last):
           File "/usr/lib/python3.5/runpy.py", line 184, in _run_module_as_main
@@ -50,12 +52,13 @@
         ValueError: Function has keyword-only arguments or annotations, use getfullargspec() API which can support them
 
 3.  Other improvements include:
+
     - the cache decorators operate as:
-        PER-INSTANCE caches for class instances, provided the first parameter 
-            is named "self"; 
-        PER-CLASS caches for classmethods, provided the first parameter is 
-            named "cls";
-        PER-FUNCTION caches for staticmethods and plain functions
+        - PER-INSTANCE caches for class instances, provided the first parameter 
+          is named "self"; 
+        - PER-CLASS caches for classmethods, provided the first parameter is 
+          named "cls";
+        - PER-FUNCTION caches for staticmethods and plain functions
         
     - keyword arguments are supported
     
@@ -63,10 +66,11 @@
       cache decorator)
     
     - Note that this sort of cache relies on the generation of a STRING KEY
-      from the function arguments. It uses the hex(id()) function for self/cls
-      arguments, and the to_str() function, passed as a parameter, for others
-      (for which the default is "repr"; see discussion below as to why "repr"
-      is suitable while "str" is not).
+      from the function arguments. It uses the ``hex(id())`` function for
+      ``self``/``cls`` arguments, and the ``to_str()`` function, passed as a
+      parameter, for others (for which the default is ``"repr"``; see
+      discussion below as to why ``"repr"`` is suitable while ``"str"`` is
+      not).
 
 """  # noqa
 
